nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ctrl

Struct Ctrl 

#[repr(transparent)]
pub struct Ctrl(pub u32);
Control Register

Tuple Fields

0: u32

Implementations

Source

impl Ctrl

pub const fn bee_enable(&self) -> BeeEnable

BEE enable bit

pub const fn set_bee_enable(&mut self, val: BeeEnable)

BEE enable bit

pub const fn ctrl_clk_en(&self) -> bool

Clock enable input, low inactive

pub const fn set_ctrl_clk_en(&mut self, val: bool)

Clock enable input, low inactive

pub const fn ctrl_sftrst_n(&self) -> bool

Soft reset input, low active

pub const fn set_ctrl_sftrst_n(&mut self, val: bool)

Soft reset input, low active

pub const fn key_valid(&self) -> bool

AES-128 key is ready Load AES key by changing this bit from 0 to 1.

pub const fn set_key_valid(&mut self, val: bool)

AES-128 key is ready Load AES key by changing this bit from 0 to 1.

pub const fn key_region_sel(&self) -> KeyRegionSel

AES key region select

pub const fn set_key_region_sel(&mut self, val: KeyRegionSel)

AES key region select

pub const fn ac_prot_en(&self) -> bool

Enable access permission control When AC_PROT_EN is asserted, all encrypted regions are limited to be ARM core access only

pub const fn set_ac_prot_en(&mut self, val: bool)

Enable access permission control When AC_PROT_EN is asserted, all encrypted regions are limited to be ARM core access only

pub const fn little_endian(&self) -> LittleEndian

Endian swap control for the 16 bytes input and output data of AES core.

pub const fn set_little_endian(&mut self, val: LittleEndian)

Endian swap control for the 16 bytes input and output data of AES core.

pub const fn security_level_r0(&self) -> u8

Security level of the allowed access for memory region0

pub const fn set_security_level_r0(&mut self, val: u8)

Security level of the allowed access for memory region0

pub const fn ctrl_aes_mode_r0(&self) -> CtrlAesModeR0

AES mode of region0

pub const fn set_ctrl_aes_mode_r0(&mut self, val: CtrlAesModeR0)

AES mode of region0

pub const fn security_level_r1(&self) -> u8

Security level of the allowed access for memory region1

pub const fn set_security_level_r1(&mut self, val: u8)

Security level of the allowed access for memory region1

pub const fn ctrl_aes_mode_r1(&self) -> CtrlAesModeR1

AES mode of region1

pub const fn set_ctrl_aes_mode_r1(&mut self, val: CtrlAesModeR1)

AES mode of region1

pub const fn bee_enable_lock(&self) -> bool

Lock bit for bee_enable

pub const fn set_bee_enable_lock(&mut self, val: bool)

Lock bit for bee_enable

pub const fn ctrl_clk_en_lock(&self) -> bool

Lock bit for ctrl_clk_en

pub const fn set_ctrl_clk_en_lock(&mut self, val: bool)

Lock bit for ctrl_clk_en

pub const fn ctrl_sftrst_n_lock(&self) -> bool

Lock bit for ctrl_sftrst

pub const fn set_ctrl_sftrst_n_lock(&mut self, val: bool)

Lock bit for ctrl_sftrst

pub const fn region1_addr_lock(&self) -> bool

Lock bit for region1 address boundary

pub const fn set_region1_addr_lock(&mut self, val: bool)

Lock bit for region1 address boundary

pub const fn key_valid_lock(&self) -> bool

Lock bit for key_valid

pub const fn set_key_valid_lock(&mut self, val: bool)

Lock bit for key_valid

pub const fn key_region_sel_lock(&self) -> bool

Lock bit for key_region_sel

pub const fn set_key_region_sel_lock(&mut self, val: bool)

Lock bit for key_region_sel

pub const fn ac_prot_en_lock(&self) -> bool

Lock bit for ac_prot

pub const fn set_ac_prot_en_lock(&mut self, val: bool)

Lock bit for ac_prot

pub const fn little_endian_lock(&self) -> bool

Lock bit for little_endian

pub const fn set_little_endian_lock(&mut self, val: bool)

Lock bit for little_endian

pub const fn security_level_r0_lock(&self) -> u8

Lock bits for security_level_r0

pub const fn set_security_level_r0_lock(&mut self, val: u8)

Lock bits for security_level_r0

pub const fn ctrl_aes_mode_r0_lock(&self) -> bool

Lock bit for region0 ctrl_aes_mode

pub const fn set_ctrl_aes_mode_r0_lock(&mut self, val: bool)

Lock bit for region0 ctrl_aes_mode

pub const fn region0_key_lock(&self) -> bool

Lock bit for region0 AES key

pub const fn set_region0_key_lock(&mut self, val: bool)

Lock bit for region0 AES key

pub const fn security_level_r1_lock(&self) -> u8

Lock bits for security_level_r1

pub const fn set_security_level_r1_lock(&mut self, val: u8)

Lock bits for security_level_r1

pub const fn ctrl_aes_mode_r1_lock(&self) -> bool

Lock bit for region1 ctrl_aes_mode

pub const fn set_ctrl_aes_mode_r1_lock(&mut self, val: bool)

Lock bit for region1 ctrl_aes_mode

pub const fn region1_key_lock(&self) -> bool

Lock bit for region1 AES key

pub const fn set_region1_key_lock(&mut self, val: bool)

Lock bit for region1 AES key