#[repr(transparent)]pub struct Ctrl(pub u32);Expand description
Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Ctrl
impl Ctrl
Sourcepub const fn bee_enable(&self) -> BeeEnable
pub const fn bee_enable(&self) -> BeeEnable
BEE enable bit
Sourcepub const fn set_bee_enable(&mut self, val: BeeEnable)
pub const fn set_bee_enable(&mut self, val: BeeEnable)
BEE enable bit
Sourcepub const fn ctrl_clk_en(&self) -> bool
pub const fn ctrl_clk_en(&self) -> bool
Clock enable input, low inactive
Sourcepub const fn set_ctrl_clk_en(&mut self, val: bool)
pub const fn set_ctrl_clk_en(&mut self, val: bool)
Clock enable input, low inactive
Sourcepub const fn ctrl_sftrst_n(&self) -> bool
pub const fn ctrl_sftrst_n(&self) -> bool
Soft reset input, low active
Sourcepub const fn set_ctrl_sftrst_n(&mut self, val: bool)
pub const fn set_ctrl_sftrst_n(&mut self, val: bool)
Soft reset input, low active
Sourcepub const fn key_valid(&self) -> bool
pub const fn key_valid(&self) -> bool
AES-128 key is ready Load AES key by changing this bit from 0 to 1.
Sourcepub const fn set_key_valid(&mut self, val: bool)
pub const fn set_key_valid(&mut self, val: bool)
AES-128 key is ready Load AES key by changing this bit from 0 to 1.
Sourcepub const fn key_region_sel(&self) -> KeyRegionSel
pub const fn key_region_sel(&self) -> KeyRegionSel
AES key region select
Sourcepub const fn set_key_region_sel(&mut self, val: KeyRegionSel)
pub const fn set_key_region_sel(&mut self, val: KeyRegionSel)
AES key region select
Sourcepub const fn ac_prot_en(&self) -> bool
pub const fn ac_prot_en(&self) -> bool
Enable access permission control When AC_PROT_EN is asserted, all encrypted regions are limited to be ARM core access only
Sourcepub const fn set_ac_prot_en(&mut self, val: bool)
pub const fn set_ac_prot_en(&mut self, val: bool)
Enable access permission control When AC_PROT_EN is asserted, all encrypted regions are limited to be ARM core access only
Sourcepub const fn little_endian(&self) -> LittleEndian
pub const fn little_endian(&self) -> LittleEndian
Endian swap control for the 16 bytes input and output data of AES core.
Sourcepub const fn set_little_endian(&mut self, val: LittleEndian)
pub const fn set_little_endian(&mut self, val: LittleEndian)
Endian swap control for the 16 bytes input and output data of AES core.
Sourcepub const fn security_level_r0(&self) -> u8
pub const fn security_level_r0(&self) -> u8
Security level of the allowed access for memory region0
Sourcepub const fn set_security_level_r0(&mut self, val: u8)
pub const fn set_security_level_r0(&mut self, val: u8)
Security level of the allowed access for memory region0
Sourcepub const fn ctrl_aes_mode_r0(&self) -> CtrlAesModeR0
pub const fn ctrl_aes_mode_r0(&self) -> CtrlAesModeR0
AES mode of region0
Sourcepub const fn set_ctrl_aes_mode_r0(&mut self, val: CtrlAesModeR0)
pub const fn set_ctrl_aes_mode_r0(&mut self, val: CtrlAesModeR0)
AES mode of region0
Sourcepub const fn security_level_r1(&self) -> u8
pub const fn security_level_r1(&self) -> u8
Security level of the allowed access for memory region1
Sourcepub const fn set_security_level_r1(&mut self, val: u8)
pub const fn set_security_level_r1(&mut self, val: u8)
Security level of the allowed access for memory region1
Sourcepub const fn ctrl_aes_mode_r1(&self) -> CtrlAesModeR1
pub const fn ctrl_aes_mode_r1(&self) -> CtrlAesModeR1
AES mode of region1
Sourcepub const fn set_ctrl_aes_mode_r1(&mut self, val: CtrlAesModeR1)
pub const fn set_ctrl_aes_mode_r1(&mut self, val: CtrlAesModeR1)
AES mode of region1
Sourcepub const fn bee_enable_lock(&self) -> bool
pub const fn bee_enable_lock(&self) -> bool
Lock bit for bee_enable
Sourcepub const fn set_bee_enable_lock(&mut self, val: bool)
pub const fn set_bee_enable_lock(&mut self, val: bool)
Lock bit for bee_enable
Sourcepub const fn ctrl_clk_en_lock(&self) -> bool
pub const fn ctrl_clk_en_lock(&self) -> bool
Lock bit for ctrl_clk_en
Sourcepub const fn set_ctrl_clk_en_lock(&mut self, val: bool)
pub const fn set_ctrl_clk_en_lock(&mut self, val: bool)
Lock bit for ctrl_clk_en
Sourcepub const fn ctrl_sftrst_n_lock(&self) -> bool
pub const fn ctrl_sftrst_n_lock(&self) -> bool
Lock bit for ctrl_sftrst
Sourcepub const fn set_ctrl_sftrst_n_lock(&mut self, val: bool)
pub const fn set_ctrl_sftrst_n_lock(&mut self, val: bool)
Lock bit for ctrl_sftrst
Sourcepub const fn region1_addr_lock(&self) -> bool
pub const fn region1_addr_lock(&self) -> bool
Lock bit for region1 address boundary
Sourcepub const fn set_region1_addr_lock(&mut self, val: bool)
pub const fn set_region1_addr_lock(&mut self, val: bool)
Lock bit for region1 address boundary
Sourcepub const fn key_valid_lock(&self) -> bool
pub const fn key_valid_lock(&self) -> bool
Lock bit for key_valid
Sourcepub const fn set_key_valid_lock(&mut self, val: bool)
pub const fn set_key_valid_lock(&mut self, val: bool)
Lock bit for key_valid
Sourcepub const fn key_region_sel_lock(&self) -> bool
pub const fn key_region_sel_lock(&self) -> bool
Lock bit for key_region_sel
Sourcepub const fn set_key_region_sel_lock(&mut self, val: bool)
pub const fn set_key_region_sel_lock(&mut self, val: bool)
Lock bit for key_region_sel
Sourcepub const fn ac_prot_en_lock(&self) -> bool
pub const fn ac_prot_en_lock(&self) -> bool
Lock bit for ac_prot
Sourcepub const fn set_ac_prot_en_lock(&mut self, val: bool)
pub const fn set_ac_prot_en_lock(&mut self, val: bool)
Lock bit for ac_prot
Sourcepub const fn little_endian_lock(&self) -> bool
pub const fn little_endian_lock(&self) -> bool
Lock bit for little_endian
Sourcepub const fn set_little_endian_lock(&mut self, val: bool)
pub const fn set_little_endian_lock(&mut self, val: bool)
Lock bit for little_endian
Sourcepub const fn security_level_r0_lock(&self) -> u8
pub const fn security_level_r0_lock(&self) -> u8
Lock bits for security_level_r0
Sourcepub const fn set_security_level_r0_lock(&mut self, val: u8)
pub const fn set_security_level_r0_lock(&mut self, val: u8)
Lock bits for security_level_r0
Sourcepub const fn ctrl_aes_mode_r0_lock(&self) -> bool
pub const fn ctrl_aes_mode_r0_lock(&self) -> bool
Lock bit for region0 ctrl_aes_mode
Sourcepub const fn set_ctrl_aes_mode_r0_lock(&mut self, val: bool)
pub const fn set_ctrl_aes_mode_r0_lock(&mut self, val: bool)
Lock bit for region0 ctrl_aes_mode
Sourcepub const fn region0_key_lock(&self) -> bool
pub const fn region0_key_lock(&self) -> bool
Lock bit for region0 AES key
Sourcepub const fn set_region0_key_lock(&mut self, val: bool)
pub const fn set_region0_key_lock(&mut self, val: bool)
Lock bit for region0 AES key
Sourcepub const fn security_level_r1_lock(&self) -> u8
pub const fn security_level_r1_lock(&self) -> u8
Lock bits for security_level_r1
Sourcepub const fn set_security_level_r1_lock(&mut self, val: u8)
pub const fn set_security_level_r1_lock(&mut self, val: u8)
Lock bits for security_level_r1
Sourcepub const fn ctrl_aes_mode_r1_lock(&self) -> bool
pub const fn ctrl_aes_mode_r1_lock(&self) -> bool
Lock bit for region1 ctrl_aes_mode
Sourcepub const fn set_ctrl_aes_mode_r1_lock(&mut self, val: bool)
pub const fn set_ctrl_aes_mode_r1_lock(&mut self, val: bool)
Lock bit for region1 ctrl_aes_mode
Sourcepub const fn region1_key_lock(&self) -> bool
pub const fn region1_key_lock(&self) -> bool
Lock bit for region1 AES key
Sourcepub const fn set_region1_key_lock(&mut self, val: bool)
pub const fn set_region1_key_lock(&mut self, val: bool)
Lock bit for region1 AES key